/*
 * #%L
 * *********************************************************************************************************************
 * 
 * SolidBlue - open source safe data
 * http://solidblue.tidalwave.it - hg clone https://bitbucket.org/tidalwave/solidblue-src
 * %%
 * Copyright (C) 2011 - 2013 Tidalwave s.a.s. (http://tidalwave.it)
 * %%
 * *********************************************************************************************************************
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 * 
 * *********************************************************************************************************************
 * 
 * $Id$
 * 
 * *********************************************************************************************************************
 * #L%
 */
package it.tidalwave.actor.io.filescan;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.nio.file.Path;
import it.tidalwave.actor.MessageSupport;
import it.tidalwave.actor.annotation.Message;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import lombok.experimental.Wither;
import static lombok.AccessLevel.*;

/***********************************************************************************************************************
 * 
 * @stereotype Message
 * 
 * A message which notifies that an error has been discovered on a file.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Message @Immutable
@RequiredArgsConstructor(access=PRIVATE) @EqualsAndHashCode(callSuper=false) @ToString(callSuper=false)
public class FileDamageDetectedMessage extends MessageSupport
  {
    @Nonnull @Getter
    private final Path path;  
    
    @Nonnull @Wither @Getter
    private final Throwable cause;
    
    @Nonnull
    public static FileDamageDetectedMessage forPath (final @Nonnull Path path)
      {
        return new FileDamageDetectedMessage(path, new Exception());  
      }
  }
